==> jc-1.4.0.tar.gz: polyglot/util/TypeInputStream.h <==
// public class polyglot.util.TypeInputStream

// class file dependencies
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 4008cd22e279a8c3 java_io_ObjectInputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a972375aaa3e5415 polyglot_util_TypeInputStream

// header file dependencies
// @dep_header java_io_ObjectInputStream

#include "java/io/ObjectInputStream.h"

#ifndef _JC_polyglot_util_TypeInputStream_H_
#define _JC_polyglot_util_TypeInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_util_TypeInputStream$sub_refs	_jc_polyglot_util_TypeInputStream$sub_refs;
typedef struct _jc_polyglot_util_TypeInputStream$sub_nonrefs	_jc_polyglot_util_TypeInputStream$sub_nonrefs;
typedef struct _jc_polyglot_util_TypeInputStream$refs	_jc_polyglot_util_TypeInputStream$refs;
typedef struct _jc_polyglot_util_TypeInputStream$nonrefs	_jc_polyglot_util_TypeInputStream$nonrefs;
typedef struct _jc_polyglot_util_TypeInputStream$object	_jc_polyglot_util_TypeInputStream$object;

typedef const struct _jc_polyglot_util_TypeInputStream$vmethods	_jc_polyglot_util_TypeInputStream$vmethods;
typedef const struct _jc_polyglot_util_TypeInputStream$vtable	_jc_polyglot_util_TypeInputStream$vtable;
typedef const struct _jc_polyglot_util_TypeInputStream$vtype	_jc_polyglot_util_TypeInputStream$vtype;

// Constructors
extern void _jc_polyglot_util_TypeInputStream$method$_init$7882f96e2dd262a0(_jc_env *, struct _jc_polyglot_util_TypeInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_util_TypeInputStream$method$getTypeSystem$305d980ff329279f(_jc_env *, struct _jc_polyglot_util_TypeInputStream$object *);
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_TypeInputStream$method$resolveObject$a7e50533aa1dcafd(_jc_env *, struct _jc_polyglot_util_TypeInputStream$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_TypeInputStream$method_info$getTypeSystem$305d980ff329279f;
extern _jc_method _jc_polyglot_util_TypeInputStream$method_info$resolveObject$a7e50533aa1dcafd;

// Virtual methods structure
struct _jc_polyglot_util_TypeInputStream$vmethods {
	struct _jc_object	*(*getTypeSystem$305d980ff329279f)(_jc_env *, struct _jc_polyglot_util_TypeInputStream$object *);
	struct _jc_java_lang_Object$object	*(*resolveObject$a7e50533aa1dcafd)(_jc_env *, struct _jc_polyglot_util_TypeInputStream$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_polyglot_util_TypeInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_ObjectInputStream$vmethods	java_io_ObjectInputStream;
	_jc_polyglot_util_TypeInputStream$vmethods	polyglot_util_TypeInputStream;
};

// Vtype
struct _jc_polyglot_util_TypeInputStream$vtype {
	_jc_type			type;
	_jc_polyglot_util_TypeInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_TypeInputStream$sub_refs {
	struct _jc_object	*ts;
	struct _jc_object	*cache;
};

// Reference instance fields (object)
struct _jc_polyglot_util_TypeInputStream$refs {
    _jc_polyglot_util_TypeInputStream$sub_refs	polyglot_util_TypeInputStream;
    _jc_java_io_ObjectInputStream$sub_refs	java_io_ObjectInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_TypeInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_TypeInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_ObjectInputStream$sub_nonrefs	java_io_ObjectInputStream;
    _jc_polyglot_util_TypeInputStream$sub_nonrefs	polyglot_util_TypeInputStream;
};

// Object instance structure
struct _jc_polyglot_util_TypeInputStream$object {
	_jc_polyglot_util_TypeInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_TypeInputStream$vtype	*vtype;
	_jc_polyglot_util_TypeInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_TypeInputStream$vtype _jc_polyglot_util_TypeInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_TypeInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_TypeInputStream$class_object;

#endif	/* _JC_polyglot_util_TypeInputStream_H_ */

==> jc-1.4.5.tar.gz: polyglot/util/TypeInputStream.h <==
// public class polyglot.util.TypeInputStream

// class file dependencies
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class d8257ba70d6d4735 java_io_ObjectInputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a972375aaa3e5415 polyglot_util_TypeInputStream

// header file dependencies
// @dep_header java_io_ObjectInputStream

#include "java/io/ObjectInputStream.h"

#ifndef _JC_polyglot_util_TypeInputStream_H_
#define _JC_polyglot_util_TypeInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_util_TypeInputStream$sub_refs	_jc_polyglot_util_TypeInputStream$sub_refs;
typedef struct _jc_polyglot_util_TypeInputStream$sub_nonrefs	_jc_polyglot_util_TypeInputStream$sub_nonrefs;
typedef struct _jc_polyglot_util_TypeInputStream$refs	_jc_polyglot_util_TypeInputStream$refs;
typedef struct _jc_polyglot_util_TypeInputStream$nonrefs	_jc_polyglot_util_TypeInputStream$nonrefs;
typedef struct _jc_polyglot_util_TypeInputStream$object	_jc_polyglot_util_TypeInputStream$object;

typedef const struct _jc_polyglot_util_TypeInputStream$vmethods	_jc_polyglot_util_TypeInputStream$vmethods;
typedef const struct _jc_polyglot_util_TypeInputStream$vtable	_jc_polyglot_util_TypeInputStream$vtable;
typedef const struct _jc_polyglot_util_TypeInputStream$vtype	_jc_polyglot_util_TypeInputStream$vtype;

// Constructors
extern void _jc_polyglot_util_TypeInputStream$method$_init$7882f96e2dd262a0(_jc_env *, struct _jc_polyglot_util_TypeInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_util_TypeInputStream$method$getTypeSystem$305d980ff329279f(_jc_env *, struct _jc_polyglot_util_TypeInputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_TypeInputStream$method$resolveObject$a7e50533aa1dcafd(_jc_env *, struct _jc_polyglot_util_TypeInputStream$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_TypeInputStream$method_info$getTypeSystem$305d980ff329279f;
extern _jc_method _jc_polyglot_util_TypeInputStream$method_info$resolveObject$a7e50533aa1dcafd;

// Virtual methods structure
struct _jc_polyglot_util_TypeInputStream$vmethods {
	struct _jc_object	*(*getTypeSystem$305d980ff329279f)(_jc_env *, struct _jc_polyglot_util_TypeInputStream$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*resolveObject$a7e50533aa1dcafd)(_jc_env *, struct _jc_polyglot_util_TypeInputStream$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_TypeInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_ObjectInputStream$vmethods	java_io_ObjectInputStream;
	_jc_polyglot_util_TypeInputStream$vmethods	polyglot_util_TypeInputStream;
};

// Vtype
struct _jc_polyglot_util_TypeInputStream$vtype {
	_jc_type			type;
	_jc_polyglot_util_TypeInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_TypeInputStream$sub_refs {
	struct _jc_object	*ts;
	struct _jc_object	*cache;
};

// Reference instance fields (object)
struct _jc_polyglot_util_TypeInputStream$refs {
    _jc_polyglot_util_TypeInputStream$sub_refs	polyglot_util_TypeInputStream;
    _jc_java_io_ObjectInputStream$sub_refs	java_io_ObjectInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_TypeInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_TypeInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_ObjectInputStream$sub_nonrefs	java_io_ObjectInputStream;
    _jc_polyglot_util_TypeInputStream$sub_nonrefs	polyglot_util_TypeInputStream;
};

// Object instance structure
struct _jc_polyglot_util_TypeInputStream$object {
	_jc_polyglot_util_TypeInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_TypeInputStream$vtype	*vtype;
	_jc_polyglot_util_TypeInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_TypeInputStream$vtype _jc_polyglot_util_TypeInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_TypeInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_TypeInputStream$class_object;

#endif	/* _JC_polyglot_util_TypeInputStream_H_ */
